@@ -2,7 +2,7 @@ import os, sys
 curr_dir = ''.join([elem + os.sep for elem in __file__.split(os.sep)[:-1]])
 sys.path += [curr_dir]
 
-__version__ = '0.5301'
+__version__ = '0.5303'
 
 from ooVar import oovar, oovars
 #from ooFun import _getAllAttachedConstraints, broadcast, ooFun as oofun, AND, OR, NOT, NAND, NOR, XOR
@@ -34,13 +34,23 @@ except ImportError:
     
 from ooarray import ooarray
 from numpy import ndarray
+#def IMPLICATION(condition, *args):
+#    if condition is False: 
+#        return True
+#    if len(args) == 1 and isinstance(args[0], (tuple, set, list, ndarray)):
+#        return ooarray([IMPLICATION(condition, elem) for elem in args[0]]) if condition is not True else args[0]
+#    elif len(args) > 1:
+#        return ooarray([IMPLICATION(condition, elem) for elem in args]) if condition is not True else args
+#    return NOT(condition & NOT(args[0])) if condition is not True else args[0]
 def IMPLICATION(condition, *args):
     if condition is False: 
         return True
     if len(args) == 1 and isinstance(args[0], (tuple, set, list, ndarray)):
-        return ooarray([IMPLICATION(condition, elem) for elem in args[0]]) if condition is not True else args[0]
+        return OR(NOT(condition), AND(args[0]))
+        #return ooarray([IMPLICATION(condition, elem) for elem in args[0]]) if condition is not True else args[0]
     elif len(args) > 1:
-        return ooarray([IMPLICATION(condition, elem) for elem in args]) if condition is not True else args
+        return OR(NOT(condition), AND(args))
+#        return ooarray([IMPLICATION(condition, elem) for elem in args]) if condition is not True else args
     return NOT(condition & NOT(args[0])) if condition is not True else args[0]
     
 ifThen = IMPLICATION
